from enum import Enum
from typing import Literal


class CatalogGrantPrivilege(Enum):
    ALL_PRIVILEGES = "ALL_PRIVILEGES"
    APPLY_TAG = "APPLY_TAG"
    CREATE_CONNECTION = "CREATE_CONNECTION"
    CREATE_EXTERNAL_LOCATION = "CREATE_EXTERNAL_LOCATION"
    CREATE_EXTERNAL_TABLE = "CREATE_EXTERNAL_TABLE"
    CREATE_EXTERNAL_VOLUME = "CREATE_EXTERNAL_VOLUME"
    CREATE_FOREIGN_CATALOG = "CREATE_FOREIGN_CATALOG"
    CREATE_FUNCTION = "CREATE_FUNCTION"
    CREATE_MANAGED_STORAGE = "CREATE_MANAGED_STORAGE"
    CREATE_MATERIALIZED_VIEW = "CREATE_MATERIALIZED_VIEW"
    CREATE_MODEL = "CREATE_MODEL"
    CREATE_SCHEMA = "CREATE_SCHEMA"
    CREATE_STORAGE_CREDENTIAL = "CREATE_STORAGE_CREDENTIAL"
    CREATE_TABLE = "CREATE_TABLE"
    CREATE_VOLUME = "CREATE_VOLUME"
    EXECUTE = "EXECUTE"
    MANAGE = "MANAGE"
    MODIFY = "MODIFY"
    READ_VOLUME = "READ_VOLUME"
    REFRESH = "REFRESH"
    SELECT = "SELECT"
    USE_CATALOG = "USE_CATALOG"
    USE_CONNECTION = "USE_CONNECTION"
    USE_SCHEMA = "USE_SCHEMA"
    WRITE_VOLUME = "WRITE_VOLUME"


CatalogGrantPrivilegeParam = (
    Literal[
        "ALL_PRIVILEGES",
        "APPLY_TAG",
        "CREATE_CONNECTION",
        "CREATE_EXTERNAL_LOCATION",
        "CREATE_EXTERNAL_TABLE",
        "CREATE_EXTERNAL_VOLUME",
        "CREATE_FOREIGN_CATALOG",
        "CREATE_FUNCTION",
        "CREATE_MANAGED_STORAGE",
        "CREATE_MATERIALIZED_VIEW",
        "CREATE_MODEL",
        "CREATE_SCHEMA",
        "CREATE_STORAGE_CREDENTIAL",
        "CREATE_TABLE",
        "CREATE_VOLUME",
        "EXECUTE",
        "MANAGE",
        "MODIFY",
        "READ_VOLUME",
        "REFRESH",
        "SELECT",
        "USE_CATALOG",
        "USE_CONNECTION",
        "USE_SCHEMA",
        "WRITE_VOLUME",
    ]
    | CatalogGrantPrivilege
)



from dataclasses import dataclass
from typing import TYPE_CHECKING, TypedDict

from databricks.bundles.core._transform import _transform
from databricks.bundles.core._transform_to_json import _transform_to_json_value
from databricks.bundles.core._variable import VariableOr, VariableOrOptional

if TYPE_CHECKING:
    from typing_extensions import Self


@dataclass(kw_only=True)
class AutoFullRefreshPolicy:
    """
    Policy for auto full refresh.
    """

    enabled: VariableOr[bool]
    """
    (Required, Mutable) Whether to enable auto full refresh or not.
    """

    min_interval_hours: VariableOrOptional[int] = None
    """
    (Optional, Mutable) Specify the minimum interval in hours between the timestamp
    at which a table was last full refreshed and the current timestamp for triggering auto full
    If unspecified and autoFullRefresh is enabled then by default min_interval_hours is 24 hours.
    """

    @classmethod
    def from_dict(cls, value: "AutoFullRefreshPolicyDict") -> "Self":
        return _transform(cls, value)

    def as_dict(self) -> "AutoFullRefreshPolicyDict":
        return _transform_to_json_value(self)  # type:ignore


class AutoFullRefreshPolicyDict(TypedDict, total=False):
    """"""

    enabled: VariableOr[bool]
    """
    (Required, Mutable) Whether to enable auto full refresh or not.
    """

    min_interval_hours: VariableOrOptional[int]
    """
    (Optional, Mutable) Specify the minimum interval in hours between the timestamp
    at which a table was last full refreshed and the current timestamp for triggering auto full
    If unspecified and autoFullRefresh is enabled then by default min_interval_hours is 24 hours.
    """


AutoFullRefreshPolicyParam = AutoFullRefreshPolicyDict | AutoFullRefreshPolicy



__all__ = [
    "Catalog",
    "CatalogDict",
    "CatalogGrant",
    "CatalogGrantDict",
    "CatalogGrantParam",
    "CatalogGrantPrivilege",
    "CatalogGrantPrivilegeParam",
    "CatalogParam",
    "Lifecycle",
    "LifecycleDict",
    "LifecycleParam",
]


from databricks.bundles.catalogs._models.catalog import (
    Catalog,
    CatalogDict,
    CatalogParam,
)
from databricks.bundles.catalogs._models.catalog_grant import (
    CatalogGrant,
    CatalogGrantDict,
    CatalogGrantParam,
)
from databricks.bundles.catalogs._models.catalog_grant_privilege import (
    CatalogGrantPrivilege,
    CatalogGrantPrivilegeParam,
)
from databricks.bundles.catalogs._models.lifecycle import (
    Lifecycle,
    LifecycleDict,
    LifecycleParam,
)



from dataclasses import dataclass
from typing import TYPE_CHECKING, TypedDict

from databricks.bundles.core._transform import _transform
from databricks.bundles.core._transform_to_json import _transform_to_json_value
from databricks.bundles.core._variable import VariableOrOptional
from databricks.bundles.jobs._models.hardware_accelerator_type import (
    HardwareAcceleratorType,
    HardwareAcceleratorTypeParam,
)

if TYPE_CHECKING:
    from typing_extensions import Self


@dataclass(kw_only=True)
class Compute:
    """"""

    hardware_accelerator: VariableOrOptional[HardwareAcceleratorType] = None
    """
    Hardware accelerator configuration for Serverless GPU workloads.
    """

    @classmethod
    def from_dict(cls, value: "ComputeDict") -> "Self":
        return _transform(cls, value)

    def as_dict(self) -> "ComputeDict":
        return _transform_to_json_value(self)  # type:ignore


class ComputeDict(TypedDict, total=False):
    """"""

    hardware_accelerator: VariableOrOptional[HardwareAcceleratorTypeParam]
    """
    Hardware accelerator configuration for Serverless GPU workloads.
    """


ComputeParam = ComputeDict | Compute



from dataclasses import dataclass, field
from typing import TYPE_CHECKING, TypedDict

from databricks.bundles.catalogs._models.catalog_grant_privilege import (
    CatalogGrantPrivilege,
    CatalogGrantPrivilegeParam,
)
from databricks.bundles.core._transform import _transform
from databricks.bundles.core._transform_to_json import _transform_to_json_value
from databricks.bundles.core._variable import VariableOr, VariableOrList

if TYPE_CHECKING:
    from typing_extensions import Self


@dataclass(kw_only=True)
class CatalogGrant:
    """"""

    principal: VariableOr[str]

    privileges: VariableOrList[CatalogGrantPrivilege] = field(default_factory=list)

    @classmethod
    def from_dict(cls, value: "CatalogGrantDict") -> "Self":
        return _transform(cls, value)

    def as_dict(self) -> "CatalogGrantDict":
        return _transform_to_json_value(self)  # type:ignore


class CatalogGrantDict(TypedDict, total=False):
    """"""

    principal: VariableOr[str]

    privileges: VariableOrList[CatalogGrantPrivilegeParam]


CatalogGrantParam = CatalogGrantDict | CatalogGrant



from enum import Enum
from typing import Literal


class HardwareAcceleratorType(Enum):
    """
    HardwareAcceleratorType: The type of hardware accelerator to use for compute workloads.
    NOTE: This enum is referenced and is intended to be used by other Databricks services
    that need to specify hardware accelerator requirements for AI compute workloads.
    """

    GPU_1X_A10 = "GPU_1xA10"
    GPU_8X_H100 = "GPU_8xH100"


HardwareAcceleratorTypeParam = (
    Literal["GPU_1xA10", "GPU_8xH100"] | HardwareAcceleratorType
)



from dataclasses import dataclass, field
from typing import TYPE_CHECKING, TypedDict

from databricks.bundles.catalogs._models.catalog_grant import (
    CatalogGrant,
    CatalogGrantParam,
)
from databricks.bundles.catalogs._models.lifecycle import Lifecycle, LifecycleParam
from databricks.bundles.core._resource import Resource
from databricks.bundles.core._transform import _transform
from databricks.bundles.core._transform_to_json import _transform_to_json_value
from databricks.bundles.core._variable import (
    VariableOr,
    VariableOrDict,
    VariableOrList,
    VariableOrOptional,
)

if TYPE_CHECKING:
    from typing_extensions import Self


@dataclass(kw_only=True)
class Catalog(Resource):
    """"""

    name: VariableOr[str]

    comment: VariableOrOptional[str] = None

    connection_name: VariableOrOptional[str] = None

    grants: VariableOrList[CatalogGrant] = field(default_factory=list)

    lifecycle: VariableOrOptional[Lifecycle] = None

    options: VariableOrDict[str] = field(default_factory=dict)

    properties: VariableOrDict[str] = field(default_factory=dict)

    provider_name: VariableOrOptional[str] = None

    share_name: VariableOrOptional[str] = None

    storage_root: VariableOrOptional[str] = None

    @classmethod
    def from_dict(cls, value: "CatalogDict") -> "Self":
        return _transform(cls, value)

    def as_dict(self) -> "CatalogDict":
        return _transform_to_json_value(self)  # type:ignore


class CatalogDict(TypedDict, total=False):
    """"""

    name: VariableOr[str]

    comment: VariableOrOptional[str]

    connection_name: VariableOrOptional[str]

    grants: VariableOrList[CatalogGrantParam]

    lifecycle: VariableOrOptional[LifecycleParam]

    options: VariableOrDict[str]

    properties: VariableOrDict[str]

    provider_name: VariableOrOptional[str]

    share_name: VariableOrOptional[str]

    storage_root: VariableOrOptional[str]


CatalogParam = CatalogDict | Catalog
